@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: io.h,v 1.44 1999/09/07 16:55:29 nisse Exp $ */
+ * $Id: io.h,v 1.45 1999/09/20 22:02:31 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -202,7 +202,7 @@ void init_consuming_read(struct io_consuming_read *self,
 #define FD_LISTEN_CALLBACK(c, fd, a) ((c)->f((c), (fd), (a)))
 
 /* FIXME: Get rid of this class, and store the user callback inside
- * accept from the io_read_callback. */
+ * the io_read_callback. */
 
 /* GABA:
    (class
@@ -220,6 +220,24 @@ void init_consuming_read(struct io_consuming_read *self,
        (callback object fd_callback)))
 */
 
+/* GABA:
+   (class
+     (name callback)
+     (vars
+       (f method void)))
+*/
+
+#define CALLBACK(c) ((c)->f(c))
+
+/* GABA:
+   (class
+     (name callout)
+     (vars
+       (next object callout)
+       (action object callback)
+       (when . time_t)))
+*/
+
 #if 0
 struct callout
 {
