@@ -1,6 +1,6 @@
 /* lsh.h
  *
- * $Id: lsh.h,v 1.8 1999/09/07 20:07:58 nisse Exp $ */
+ * $Id: lsh.h,v 1.9 1999/09/20 22:07:24 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -98,6 +98,7 @@ struct lsh_string
   UINT8 data[1];
 };
 
+#if 0
 /* A closed function with no arguments */
 struct callback;
 typedef int (*callback_f)(struct callback *closure);
@@ -109,6 +110,6 @@ struct callback
 };
 
 #define CALLBACK(c) ((c)->f(c))
-
+#endif
 
 #endif /* LSH_H_INCLUDED */
