@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: publickey_crypto.h,v 1.22 1999/09/07 08:50:07 nisse Exp $ */
+ * $Id: publickey_crypto.h,v 1.24 1999/09/22 01:11:39 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -35,9 +35,21 @@
 #include "publickey_crypto.h.x"
 #undef GABA_DECLARE
 
+/* GABA:
+   (class
+     (name keypair)
+     (vars
+       (public string)
+       (private object signer)))
+*/
+
+struct keypair *make_keypair(struct lsh_string *public,
+			     struct signer *private);
+
 /* parse an ssh keyblob */
 int parse_dsa_public(struct simple_buffer *buffer,
 		     struct dsa_public *public);
+void init_dsa_public(struct dsa_public *public);
 
 struct signature_algorithm *make_dsa_algorithm(struct randomness *random);
 
