@@ -2,7 +2,7 @@
  *
  * user authorization database
  *
- * $Id: server_authorization.c,v 1.1 1999/09/06 22:03:49 nisse Exp $ */
+ * $Id: server_authorization.c,v 1.2 1999/09/21 23:04:49 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -28,7 +28,7 @@
 #include "sexp.h"
 #include "spki.h"
 #include "format.h"
-#include "server_password.h"
+#include "server_userauth.h"
 
 #include <sys/stat.h>
 #include <unistd.h>
